<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:template match="/">
		<html>
			<head>
				<title>Fate Core: <xsl:value-of select="/character/name/text()"/></title>
				<style type="text/css">
					/* Doing fonts as depicted below allows all browsers to enlarge or reduce fonts
					per the user's choice.*/
					body 
					{
					font-size:100%;  /* default font size is 16 pixels */
					font-family:Optima,sans-serif;
					} 
					p {font-size:0.75em;} /* default font size is 12 pixels */
					h6 {font-size:0.75em;} /* default font size is 12 pixels */
					h5 {font-size:1em;} /* default font size is 16 pixels */
					h4 {font-size:1.25em;} /* default font size is 20 pixels */
					h3 {font-size:1.5em;} /* default font size is 24 pixels */
					h2 {font-size:1.75em;} /* default font size is 28 pixels */
					h1 {font-size:2em;} /* default font size is 32 pixels */
					#nonborderblock
					{
					font-family:Optima,sans-serif;
					}
					#dblock
					{
					font-family:Optima,sans-serif;
					width:100%;
					border-collapse:collapse;
					}
					#dblock td,#dblock th
					{
					font-size:0.75em; /* provides 12pixel font. */
					border:1px solid #000000;
					padding:3px 7px 2px 7px;
					vertical-align:top;
					}
					#dblock th
					{
					font-size:1em;
					text-align:left;
					padding-top:5px;
					padding-bottom:4px;
					background-color:#AAAAAA;
					color:#ffffff;
					}
					#dblock tr.alt td
					{
					color:#000000;
					background-color:#DDDDDD;
					}
					#dblock td.note
					{
					font-size:0.5em;
					}
					div.title
					{
					background-color:#b0c4de;
					}
					img.right 
					{
					float:right;
					}
					
				</style>
			</head>
			<body>
				<table id="dblock" border="1">
					<!-- Row 1: ID and Portrait -->
					<tr>
						<td colspan="3" width="60%">
							<!-- ID -->
							<div class="title">
								<strong>ID<br/></strong>
							</div>
							<strong>Name: </strong>
							<xsl:value-of select="/character/name/text()"/>
							<br/>
							<strong>Description: </strong>
							<xsl:value-of select="/character/datablock[@name='ID']/data[@name='Description']/text()"/>
							<br/>
							<strong>Refresh: </strong>
							<xsl:value-of select="/character/datablock[@name='ID']/data[@name='Refresh']/text()"/>
							<!-- Aspects -->
							<xsl:for-each select="/character/datablock[@name='Aspects']/data">
								<xsl:choose>
									<xsl:when test="@renamed != ''">
										<!-- Output a title row on the first time through, only. -->
										<xsl:if test="position() = '1'">
											<div class="title">
												<strong>Aspects <br/></strong>
											</div>
										</xsl:if>
										<em>
											<strong>
												<xsl:value-of select="@renamed"/>
											</strong>
										</em>
										<xsl:if test="text() !=''">
											- <xsl:value-of select="text()"/>
										</xsl:if>
										<br/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="text() != ''">
											<xsl:if test="position() = '1'">
												<div class="title">
													<strong>Aspects <br/></strong>
												</div>
											</xsl:if>
											<xsl:if test="text() !=''">
												<xsl:value-of select="text()"/>
											</xsl:if>
											<br/>
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</td>
						<td colspan="2" width="40%">
							<img class="right" src="portrait.png" alt="Portrait"/>
						</td>
					</tr>
					<!-- Row 2: Skills and Stunts -->
					<tr>
						<!-- Skills -->
						<td colspan="2" width="40%">
							<div class="title">
								<strong>Skills<br/></strong>
							</div>
							<xsl:if test="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text() != ''">
								<strong>Legendary (+8): </strong>
								<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text() != ''">
								<strong>Epic (+7): </strong>
								<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text() != ''">
								<strong>Fantastic (+6): </strong>
								<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text() != ''">
								<strong>Superb (+5): </strong>
								<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text() != ''">
								<strong>Great (+4): </strong>
								<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text() != ''">
								<strong>Good (+3): </strong>
								<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text() != ''">
								<strong>Fair (+2): </strong>
								<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text() != ''">
								<strong>Average (+1): </strong>
								<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text()"/>
								<br/>
							</xsl:if>
							
							<!-- Stress -->
							<div class="title"><strong>Stress<br/></strong></div>
							Physical Stress: <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Physical Stress']/text()"/> 
							<xsl:if test="/character/datablock[@name='Stress']/data[@name='Physical Stress Taken']/text() != ''">
								/ <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Physical Stress Taken']/text()"/>
							</xsl:if>
							<br/>
							Mental Stress: <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Mental Stress']/text()"/>
							<xsl:if test="/character/datablock[@name='Stress']/data[@name='Mental Stress Taken']/text() != ''">
								/ <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Mental Stress Taken']/text()"/>
							</xsl:if>
							<br/>
							<xsl:if test="/character/datablock[@name='Stress']/data[@name='Extra Consequences']/text() !=''">
								Extra Consequences: <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Extra Consequences']/text()"/>
								<br/>
							</xsl:if>
							<!-- Consequences -->
							<div class="title">
								<strong>Consequences<br/></strong>
							</div>
							<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Mild']/text() !=''">
								<strong>Mild (-2): </strong>
								<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Mild']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Moderate']/text() != ''">
								<strong>Moderate (-4): </strong>
								<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Moderate']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Severe']/text() != ''">
								<strong>Severe (-6): </strong>
								<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Severe']/text()"/>
								<br/>
							</xsl:if>
							<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Extreme']/text() != ''">
								<strong>Extreme (-8): </strong>
								<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Extreme']/text()"/>
								<br/>
							</xsl:if>

						</td>
						<!-- Stunts -->
						<td colspan="3">
							<xsl:for-each select="/character/datablock[@name='Stunts']/data">
								<!-- Stunts can be renamed by the user. -->
								<xsl:choose>
									<xsl:when test="@renamed != ''">
										<xsl:choose>
											<xsl:when test="text() != ''">
												<!-- Output a title row on the first time through, only. -->
												<xsl:if test="position() = '1'">
													<div class="title">
														<strong>Stunts<br/></strong>
													</div>
												</xsl:if>
												<strong><xsl:value-of select="@renamed"/>. </strong>
												<xsl:value-of select="text()"/>
												<br/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:if test="@renamed != 'Stunt'">
													<!-- Output a title row on the first time through, only. -->
													<xsl:if test="position() = '1'">
														<div class="title">
															<strong>Stunts<br/></strong>
														</div>
													</xsl:if>
													<strong><xsl:value-of select="@renamed"/>. </strong>
													<xsl:value-of select="text()"/>
													<br/>
												</xsl:if>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="text() != ''">
											<!-- Output a title row on the first time through, only. -->
											<xsl:if test="position() = '1'">
												<strong>
													<u>Stunts</u>
												</strong>
												<br/>
											</xsl:if>
											<xsl:value-of select="text()"/>
											<br/>
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
							
							<!-- Extras -->
							<xsl:for-each select="/character/datablock[@name='Extras']/data">
								<!-- Extras can be renamed by the user. -->
								<xsl:choose>
									<xsl:when test="@renamed != ''">
										<xsl:choose>
											<xsl:when test="text() != ''">
												<!-- Output a title row on the first time through, only. -->
												<xsl:if test="position() = '1'">
													<div class="title">
														<strong>Extras<br/></strong>
													</div>
												</xsl:if>
												<strong><xsl:value-of select="@renamed"/>. </strong>
												<xsl:value-of select="text()"/>
												<br/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:if test="@renamed !='Extra'">
													<!-- Output a title row on the first time through, only. -->
													<xsl:if test="position() = '1'">
														<div class="title">
															<strong>Extras<br/></strong>
														</div>
													</xsl:if>
													<strong><xsl:value-of select="@renamed"/>. </strong>
													<xsl:value-of select="text()"/>
													<br/>
												</xsl:if>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="text() !=''">
											<!-- Output a title row on the first time through, only. -->
											<xsl:if test="position() = '1'">
												<strong>
													<u>Other Extras</u>
												</strong>
												<br/>
											</xsl:if>
											<strong><xsl:value-of select="@name"/>. </strong>
											<xsl:value-of select="text()"/>
											<br/>
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</td>
					</tr>
				</table>
				<!-- Include Journals, if available. -->
				<xsl:for-each select="//article">
					<p>
						<article>
							<xsl:attribute name="title">
								<xsl:value-of select="@title"/>
							</xsl:attribute>
							<span style="font-size:1em;font-weight:bold;color:#339900;">
								<xsl:value-of select="@title"/>
							</span>
							<br/>
							<xsl:for-each select="span">
								<span>
									<xsl:attribute name="style">
										<xsl:value-of select="@style"/>
									</xsl:attribute>
									<xsl:value-of select="text()"/>
									<xsl:if test="br">
										<br/>
									</xsl:if>
								</span>
							</xsl:for-each>
						</article>
					</p>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
