<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:template match="/">
		<html>
			<head>
				<title>Fate Core: <xsl:value-of select="/character/name/text()"/></title>
				<style typ="text/css">
					/* Doing fonts as depicted below allows all browsers to enlarge or reduce fonts
					per the user's choice.*/
					body 
					{
					font-size:100%;  /* default font size is 16 pixels */
					font-family:sans-serif;
					} 
					p {font-size:1em;} /* default font size is 12 pixels */
					h6 {font-size:1em;} /* default font size is 12 pixels */
					h5 {font-size:1.25em;} /* default font size is 16 pixels */
					h4 {font-size:1.50em;} /* default font size is 20 pixels */
					h3 {font-size:1.75em;} /* default font size is 24 pixels */
					h2 {font-size:2em;} /* default font size is 28 pixels */
					h1 {font-size:2.25em;} /* default font size is 32 pixels */
					img.right {float:right;}		
				</style>
			</head>
			<body>
				<!-- Name -->
				<h1><xsl:value-of select="/character/name/text()"/></h1>
				
				<!-- Have the portrait placed here. Get text to flow around it -->
				<img class="right" src="portrait.png" alt="Portrait"/>
				
				<!-- Description -->
				<strong>Description: </strong>
				<xsl:value-of select="/character/datablock[@name='ID']/data[@name='Description']/text()"/>
				<br/>
				<strong>Refresh: </strong>
				<xsl:value-of select="/character/datablock[@name='ID']/data[@name='Refresh']/text()"/>
				<br/>
				<strong>Current Fate Points: </strong>
				<xsl:value-of select="/character/datablock[@name='ID']/data[@name='Current Fate Points']/text()"/>
				<!-- Aspects -->
				<p>
					<xsl:for-each select="/character/datablock[@name='Aspects']/data">
						<xsl:choose>
							<xsl:when test="@renamed != ''">
								<!-- Output a title row on the first time through, only. -->
								<xsl:if test="position() = '1'">
									<strong><u>Aspects</u></strong>
									<br/>
								</xsl:if>
								<em><strong><xsl:value-of select="@renamed"/></strong></em>
								<xsl:if test="text() !=''">
									- <xsl:value-of select="text()"/>
								</xsl:if>
								
								<br/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="text() != ''">
									<xsl:if test="position() = '1'">
										<strong><u>Aspects</u></strong>
										<br/>
									</xsl:if>
									<xsl:if test="text() !=''">
										- <xsl:value-of select="text()"/>
									</xsl:if>
									<br/>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</p>
				<!-- Skills -->
				<p>
					<strong>
						<u>Skills</u>
					</strong>
					<br/>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text() != ''">
						<strong>+8: </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text() != ''">
						<strong>+7: </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text() != ''">
						<strong>+6: </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text() != ''">
						<strong>+5: </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text() != ''">
						<strong>+4: </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text() != ''">
						<strong>+3: </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text() != ''">
						<strong>+2: </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text() != ''">
						<strong>+1: </strong>
						<xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text()"/>
						<br/>
					</xsl:if>
				</p>
				<!-- Stunts -->
				<p>
					<xsl:for-each select="/character/datablock[@name='Stunts']/data">
						<!-- Stunts can be renamed by the user. -->
						<xsl:choose>
							<xsl:when test="@renamed != ''">
								<xsl:choose>
									<xsl:when test="text() != ''">
										<!-- Output a title row on the first time through, only. -->
										<xsl:if test="position() = '1'">
											<strong>
												<u>Stunts</u>
											</strong>
											<br/>
										</xsl:if>
										<strong><xsl:value-of select="@renamed"/>. </strong>
										<xsl:value-of select="text()"/>
										<br/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="@renamed != 'Stunt'">
											<!-- Output a title row on the first time through, only. -->
											<xsl:if test="position() = '1'">
												<strong>
													<u>Stunts</u>
												</strong>
												<br/>
											</xsl:if>
											<strong><xsl:value-of select="@renamed"/>. </strong>
											<xsl:value-of select="text()"/>
											<br/>
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="text() != ''">
									<!-- Output a title row on the first time through, only. -->
									<xsl:if test="position() = '1'">
										<strong>
											<u>Stunts</u>
										</strong>
										<br/>
									</xsl:if>
									<xsl:value-of select="text()"/>
									<br/>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</p>
				<!-- Extras -->
				<p>
					<xsl:for-each select="/character/datablock[@name='Extras']/data">
						<!-- Extras can be renamed by the user. -->
						<xsl:choose>
							<xsl:when test="@renamed != ''">
								<xsl:choose>
									<xsl:when test="text() != ''">
										<!-- Output a title row on the first time through, only. -->
										<xsl:if test="position() = '1'">
											<strong><u>Extras</u></strong><br />
										</xsl:if>
										<strong><xsl:value-of select="@renamed"/>. </strong><xsl:value-of select="text()"/><br />
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="@renamed !='Extra'">
										<!-- Output a title row on the first time through, only. -->
										    <xsl:if test="position() = '1'">
											    <strong><u>Extras</u></strong><br />
										    </xsl:if>
											<strong><xsl:value-of select="@renamed"/>. </strong><xsl:value-of select="text()"/><br />
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="text() !=''">
									<!-- Output a title row on the first time through, only. -->
									<xsl:if test="position() = '1'">
										<strong><u>Other Extras</u></strong><br />
									</xsl:if>
									<strong><xsl:value-of select="@name"/>. </strong><xsl:value-of select="text()"/><br />
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</p>
				<!-- Stress and Consequences -->
				<p>
					<strong><u>Stress</u></strong><br/>
					Physical Stress: <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Physical Stress']/text()"/> 
					<xsl:if test="/character/datablock[@name='Stress']/data[@name='Physical Stress Taken']/text() != ''">
						/ <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Physical Stress Taken']/text()"/>
					</xsl:if>
					<br/>
					Mental Stress: <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Mental Stress']/text()"/>
					<xsl:if test="/character/datablock[@name='Stress']/data[@name='Mental Stress Taken']/text() != ''">
						/ <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Mental Stress Taken']/text()"/>
					</xsl:if>
					<br/>
					<xsl:if test="/character/datablock[@name='Stress']/data[@name='Extra Consequences']/text() !=''">
						Extra Consequences: <xsl:value-of select="/character/datablock[@name='Stress']/data[@name='Extra Consequences']/text()"/>
						<br/>
					</xsl:if>
				</p>
				<p>
					<!-- If there is any consequence the character has, then create a consequence section, complete with title line. -->
					<xsl:choose>
						<xsl:when test="/character/datablock[@name='Consequences']/data[@name='Mild']/text() !=''">
							<strong><u>Consequences</u></strong><br/>
						</xsl:when>
						<xsl:when test="/character/datablock[@name='Consequences']/data[@name='Moderate']/text() != ''">
							<strong><u>Consequences</u></strong><br/>
						</xsl:when>
						<xsl:when test="/character/datablock[@name='Consequences']/data[@name='Severe']/text() != ''">
							<strong><u>Consequences</u></strong><br/>
						</xsl:when>
						<xsl:when test="/character/datablock[@name='Consequences']/data[@name='Extreme']/text() != ''">
							<strong><u>Consequences</u></strong><br/>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Mild']/text() !=''">
						<strong>Mild (-2): </strong>
						<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Mild']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Moderate']/text() != ''">
						<strong>Moderate (-4): </strong>
						<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Moderate']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Severe']/text() != ''">
						<strong>Severe (-6): </strong>
						<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Severe']/text()"/>
						<br/>
					</xsl:if>
					<xsl:if test="/character/datablock[@name='Consequences']/data[@name='Extreme']/text() != ''">
						<strong>Extreme (-8): </strong>
						<xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Extreme']/text()"/>
						<br/>
					</xsl:if>
				</p>
				<!-- Include Journals, if available. -->
				<xsl:for-each select="//article">
					<p>
						<article>
							<xsl:attribute name="title">
								<xsl:value-of select="@title"/>
							</xsl:attribute>
							<span style="font-size:1em;font-weight:bold;color:#339900;">
								<xsl:value-of select="@title"/>
							</span>
							<br/>
							<xsl:for-each select="span">
								<span>
									<xsl:attribute name="style">
										<xsl:value-of select="@style"/>
									</xsl:attribute>
									<xsl:value-of select="text()"/>
									<xsl:if test="br">
										<br/>
									</xsl:if>
								</span>
							</xsl:for-each>
						</article>
					</p>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
